function s = tchstd(v)
%
% tchstd - Compute standard deviation of vecot
% On inpput:
%     v: vector of length n
% On output:
%     s: standard deviation of v
% Call:
%     s = tchstd(v)
%

s = sqrt(tchvar(v));
